"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.convertStringToNumber = exports.TextRenderer = exports.StringRenderer = exports.NumberRenderer = void 0;

var _react = _interopRequireDefault(require("react"));

var _uiSchema = require("@ui-schema/ui-schema");

var _LocaleHelperText = require("../../Component/LocaleHelperText/LocaleHelperText");

var _reactUid = require("react-uid");

var _excluded = ["schema"],
    _excluded2 = ["schema"];

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var convertStringToNumber = function convertStringToNumber(value, type) {
  if (type === 'number') {
    if (isNaN(value * 1)) {
      console.error('Invalid Type: input not a number in');
      return;
    }

    return value === '' ? '' : value * 1;
  }

  return value;
};

exports.convertStringToNumber = convertStringToNumber;

var StringRenderer = function StringRenderer(_ref) {
  var schema = _ref.schema,
      value = _ref.value,
      _ref$multiline = _ref.multiline,
      multiline = _ref$multiline === void 0 ? false : _ref$multiline,
      _onChange = _ref.onChange,
      storeKeys = _ref.storeKeys,
      showValidity = _ref.showValidity,
      required = _ref.required,
      errors = _ref.errors,
      type = _ref.type,
      rows = _ref.rows;
  var format = schema.get('format');
  var uid = (0, _reactUid.useUID)();
  var Renderer = 'input';

  if (multiline) {
    Renderer = 'textarea';
  }

  var classFormGroup = ['form-group'];
  var classFormControl = ['form-control'];

  if (showValidity && errors.hasError()) {
    classFormControl.push('is-invalid');
  }

  if (showValidity && !errors.hasError()) {
    classFormGroup.push('was-validated');
  }

  return _react["default"].createElement("div", {
    className: classFormGroup.join(' ')
  }, _react["default"].createElement("label", {
    htmlFor: 'uis-' + uid
  }, _react["default"].createElement(_uiSchema.TransTitle, {
    schema: schema,
    storeKeys: storeKeys
  })), _react["default"].createElement(Renderer, {
    className: classFormControl.join(' '),
    type: format || type,
    required: required,
    rows: rows,
    value: typeof value !== 'undefined' ? value : '',
    onChange: function onChange(e) {
      var val = e.target.value;

      _onChange({
        storeKeys: storeKeys,
        scopes: ['value'],
        type: 'set',
        data: {
          value: convertStringToNumber(val, schema.get('type'))
        },
        schema: schema,
        required: required
      });
    }
  }), _react["default"].createElement(_LocaleHelperText.ValidityHelperText, {
    errors: errors,
    showValidity: showValidity,
    schema: schema
  }));
};

exports.StringRenderer = StringRenderer;

var TextRenderer = function TextRenderer(_ref2) {
  var schema = _ref2.schema,
      props = _objectWithoutProperties(_ref2, _excluded);

  return _react["default"].createElement(StringRenderer, _extends({}, props, {
    schema: schema,
    rows: schema.getIn(['view', 'rows']),
    multiline: true
  }));
};

exports.TextRenderer = TextRenderer;

var NumberRenderer = function NumberRenderer(_ref3) {
  var schema = _ref3.schema,
      props = _objectWithoutProperties(_ref3, _excluded2);

  return _react["default"].createElement(StringRenderer, _extends({}, props, {
    schema: schema,
    type: 'number'
  }));
};

exports.NumberRenderer = NumberRenderer;